@@ -1,4 +1,6 @@
 package SkipUnderscoreSubClass;
+use warnings;
+use strict;
 use base 'SkipUnderscoreBaseClass';
 
 sub in_sub_class {
