@@ -1,4 +1,6 @@
 package _NotShownBaseClass;
+use warnings;
+use strict;
 
 sub _hide_this {
   'here there be dragons';
